==> variants-cit-3.11.1%2B1.21.4-sources.jar: fr/estecka/variantscit/mixin/FeatureRendererMixin.java <==
package fr.estecka.variantscit.mixin;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import fr.estecka.variantscit.VariantsCitMod;
import net.minecraft.class_1799;
import net.minecraft.class_4073;
import net.minecraft.class_9085;
import net.minecraft.class_9331;
import net.minecraft.class_970;
import net.minecraft.class_972;
import net.minecraft.class_979;
import net.minecraft.class_988;

public class FeatureRendererMixin
{
	@Mixin(class_970.class)
	static public class Armor
	{
		@WrapOperation(
			method = { "renderArmor", "hasModel" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_972.class)
	static public class Cape
	{
		@WrapOperation(
			method = { "hasCustomModelForLayer" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_979.class)
	static public class Elytra
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_4073.class)
	static public class Horse
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_988.class)
	static public class Llama
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_9085.class)
	static public class Wolf
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}
}

==> variants-cit-4.8.1%2B1.21.6-sources.jar: fr/estecka/variantscit/mixin/FeatureRendererMixin.java <==
package fr.estecka.variantscit.mixin;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import fr.estecka.variantscit.VariantsCitMod;
import net.minecraft.class_10652;
import net.minecraft.class_1799;
import net.minecraft.class_9085;
import net.minecraft.class_9331;
import net.minecraft.class_970;
import net.minecraft.class_972;
import net.minecraft.class_979;
import net.minecraft.class_988;

public class FeatureRendererMixin
{
	@Mixin(class_970.class)
	static public class Armor
	{
		@WrapOperation(
			method = { "renderArmor", "hasModel" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_972.class)
	static public class Cape
	{
		@WrapOperation(
			method = { "hasCustomModelForLayer" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_979.class)
	static public class Elytra
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_988.class)
	static public class Llama
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_10652.class)
	static public class Saddle
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}

	@Mixin(class_9085.class)
	static public class Wolf
	{
		@WrapOperation(
			method = { "render" },
			at=@At(value="INVOKE", ordinal=0, target="net/minecraft/item/ItemStack.get(Lnet/minecraft/component/ComponentType;)Ljava/lang/Object;")
		)
		static private Object GetVariantEquippable(class_1799 stack, class_9331<?> type, Operation<?> originalOp){
			return VariantsCitMod.EQUIPABLES.GetEquipableVariant(stack, type, originalOp);
		}
	}
}
